@@ -17,6 +17,6 @@ from .rdb_repository import RdbRepository
 from .rdb_repository_factory import RdbRepositoryFactory
 from .rdb_storage_interface import RdbStorageInterface
 from .rdb_storage_interface_registry import RdbStorageInterfaceRegistry
-from .db_api_storage_interfaces import *
+from .rdb_storage_interfaces import *
 from .memory_repository import MemoryRepository
 from .memory_repository_factory import MemoryRepositoryFactory
